# About
emipy is a package for processing data of pollutant releases and pollutant transfers.
It's main target is to enable a fast output of individual data set requests and to provide visualisation options.

The data are provided by the [European Environment Agency](https://www.eea.europa.eu/data-and-maps/data/member-states-reporting-art-7-under-the-european-pollutant-release-and-transfer-register-e-prtr-regulation-23).

# Documentation
For the documentation take a look over [here](https://emipy.readthedocs.io/en/latest/).


